@@ -5,7 +5,7 @@ from __future__ import division
 from affine import Affine
 from shapely.geometry import shape
 import numpy as np
-import numpy.distutils.system_info as sysinfo
+import platform
 import warnings
 
 from .io import read_features, Raster
@@ -45,7 +45,8 @@ def gen_zonal_stats(
         zone_func=None,
         raster_out=False,
         prefix=None,
-        geojson_out=False, **kwargs):
+        geojson_out=False, 
+        boundless=True, **kwargs):
     """Zonal statistics of raster values aggregated to vector geometries.
 
     Parameters
@@ -56,7 +57,7 @@ def gen_zonal_stats(
         If ndarray is passed, the ``affine`` kwarg is required.
 
     layer: int or string, optional
-        If `vectors` is a path to an fiona source,
+        If `vectors` is a path to a fiona source,
         specify the vector layer to use either by name or number.
         defaults to 0
 
@@ -111,7 +112,10 @@ def gen_zonal_stats(
         Original feature geometry and properties will be retained
         with zonal stats appended as additional properties.
         Use with `prefix` to ensure unique and meaningful property names.
-
+    
+    boundless: boolean
+        Allow features that extend beyond the raster dataset’s extent, default: True
+        Cells outside dataset extents are treated as nodata.
         
     Returns
     -------
@@ -153,7 +157,7 @@ def gen_zonal_stats(
 
             geom_bounds = tuple(geom.bounds)
 
-            fsrc = rast.read(bounds=geom_bounds)
+            fsrc = rast.read(bounds=geom_bounds, boundless=boundless)
 
             # rasterized geometry
             rv_array = rasterize_geom(geom, like=fsrc, all_touched=all_touched)
@@ -177,7 +181,7 @@ def gen_zonal_stats(
             # If we're on 64 bit platform and the array is an integer type
             # make sure we cast to 64 bit to avoid overflow.
             # workaround for https://github.com/numpy/numpy/issues/8433
-            if sysinfo.platform_bits == 64 and \
+            if platform.architecture()[0] == '64bit' and \
                     masked.dtype != np.int64 and \
                     issubclass(masked.dtype.type, np.integer):
                 masked = masked.astype(np.int64)
